@@ -9,15 +9,15 @@
 #include <wx/wxprec.h>
 
 //(*Headers(KodersDialog)
+#include "scrollingdialog.h"
 #include <wx/button.h>
 #include <wx/choice.h>
-#include <wx/dialog.h>
 #include <wx/sizer.h>
 #include <wx/stattext.h>
 #include <wx/textctrl.h>
 //*)
 
-class KodersDialog: public wxDialog
+class KodersDialog: public wxScrollingDialog
 {
 	public:
 
@@ -27,15 +27,13 @@ class KodersDialog: public wxDialog
 		void     SetSearch(const wxString &search);
 		wxString GetSearch() const;
 		wxString GetLanguage() const;
-		wxString GetLicense() const;
 
 		//(*Identifiers(KodersDialog)
-		static const long ID_LBL_INTRO;
-		static const long ID_TXT_SEARCH;
-		static const long ID_BTN_SEARCH;
-		static const long ID_LBL_FILTER;
-		static const long ID_CHO_LANGUAGES;
-		static const long ID_CHO_LICENSES;
+		static const wxWindowID ID_LBL_INTRO;
+		static const wxWindowID ID_TXT_SEARCH;
+		static const wxWindowID ID_BTN_SEARCH;
+		static const wxWindowID ID_LBL_FILTER;
+		static const wxWindowID ID_CHO_LANGUAGES;
 		//*)
 
 	protected:
@@ -45,16 +43,15 @@ class KodersDialog: public wxDialog
 		//*)
 
 		//(*Declarations(KodersDialog)
-		wxBoxSizer* bszMain;
-		wxBoxSizer* bszIntro;
-		wxStaticText* lblIntro;
-		wxBoxSizer* bszSearch;
-		wxTextCtrl* txtSearch;
-		wxButton* btnSearch;
 		wxBoxSizer* bszFilter;
-		wxStaticText* lblFilter;
+		wxBoxSizer* bszIntro;
+		wxBoxSizer* bszMain;
+		wxBoxSizer* bszSearch;
+		wxButton* btnSearch;
 		wxChoice* choLanguages;
-		wxChoice* choLicenses;
+		wxStaticText* lblFilter;
+		wxStaticText* lblIntro;
+		wxTextCtrl* txtSearch;
 		//*)
 
 	private:
