@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 9034 $
- * $Id: help_plugin.cpp 9034 2013-05-04 03:02:57Z biplab $
- * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/help_plugin/help_plugin.cpp $
+ * $Revision: 13201 $
+ * $Id: help_plugin.cpp 13201 2023-02-08 14:39:53Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/help_plugin/help_plugin.cpp $
  */
 
 #include "sdk.h"
@@ -12,7 +12,7 @@
   #include <wx/filename.h>
   #include <wx/fs_zip.h>
   #include <wx/intl.h>
-  #include <wx/menuitem.h>
+  #include <wx/menu.h>
   #include <wx/process.h>
   #include <wx/xrc/xmlres.h>
   #include "cbeditor.h"
@@ -24,11 +24,11 @@
   #include "macrosmanager.h"
   #include "manager.h"
   #include "projectmanager.h"
+  #include "scriptingmanager.h"
 #endif
 
 #include <vector>
 
-#include <wx/textdlg.h>
 #include <wx/mimetype.h>
 #include <wx/help.h> //(wxWindows chooses the appropriate help controller class)
 #include <wx/helpbase.h> //(wxHelpControllerBase class)
@@ -41,16 +41,13 @@
 #include <wx/thread.h>
 #endif
 
-#include <cbstyledtextctrl.h>
-#include <sc_base_types.h>
-#include <sqplus.h>
-
+#include "cbstyledtextctrl.h"
+#include "scripting/bindings/sc_utils.h"
+#include "scripting/bindings/sc_typeinfo_all.h"
 
 #include "help_plugin.h"
 #include "MANFrame.h"
 
-
-
 // 20 wasn't enough
 #define MAX_HELP_ITEMS 32
 
@@ -59,7 +56,7 @@ int idHelpMenus[MAX_HELP_ITEMS];
 // Register the plugin
 namespace
 {
-    PluginRegistrant<HelpPlugin> reg(_T("HelpPlugin"));
+    PluginRegistrant<HelpPlugin> reg("HelpPlugin");
     int idViewMANViewer = wxNewId();
 };
 
@@ -71,34 +68,6 @@ END_EVENT_TABLE()
 #ifdef __WXMSW__
 namespace
 {
-#ifndef UNICODE
-  typedef HWND (WINAPI *HTMLHELP)(HWND, LPCSTR, UINT, DWORD);
-  #define HTMLHELP_NAME "HtmlHelpA"
-#else // ANSI
-  typedef HWND (WINAPI *HTMLHELP)(HWND, LPCWSTR, UINT, DWORD);
-  #define HTMLHELP_NAME "HtmlHelpW"
-#endif
-
-  // ocx symbol handle
-  HTMLHELP fp_htmlHelp = 0;
-  HMODULE ocx_module = 0;
-
-  // it's used to search by keyword
-  struct cbHH_AKLINK
-  {
-    int      cbStruct;
-    BOOL     fReserved;
-    LPCTSTR  pszKeywords;
-    LPCTSTR  pszUrl;
-    LPCTSTR  pszMsgText;
-    LPCTSTR  pszMsgTitle;
-    LPCTSTR  pszWindow;
-    BOOL     fIndexOnFail;
-  };
-
-  // the command to search by keyword
-  const UINT cbHH_KEYWORD_LOOKUP = 0x000D;
-
   // This little class helps to fix a problem when the help file is CHM and the
   // keyword throws many results
   class LaunchCHMThread : public wxThread
@@ -121,30 +90,7 @@ namespace
 
   wxThread::ExitCode LaunchCHMThread::Entry()
   {
-    if (fp_htmlHelp) // do it our way if we can
-    {
-      cbHH_AKLINK link;
-
-      link.cbStruct     = sizeof(cbHH_AKLINK);
-      link.fReserved    = FALSE;
-      link.pszKeywords  = m_keyword.c_str();
-      link.pszUrl       = NULL;
-      link.pszMsgText   = NULL;
-      link.pszMsgTitle  = NULL;
-      link.pszWindow    = NULL;
-      link.fIndexOnFail = TRUE;
-
-      #if defined(_WIN64) | defined(WIN64)
-      fp_htmlHelp(0L, (const wxChar*)m_filename, cbHH_KEYWORD_LOOKUP, (DWORDLONG)&link);
-      #else
-      fp_htmlHelp(0L, (const wxChar*)m_filename, cbHH_KEYWORD_LOOKUP, (DWORD)&link);
-      #endif
-    }
-    else // do it the wx way then (which is the same thing, except for the 0L in the call to fp_htmlHelp)
-    {
-      m_helpctl.KeywordSearch(m_keyword);
-    }
-
+    m_helpctl.KeywordSearch(m_keyword);
     return 0;
   }
 }
@@ -154,44 +100,30 @@ HelpPlugin::HelpPlugin()
 : m_pMenuBar(0), m_LastId(0), m_manFrame(0)
 {
   //ctor
-  if (!Manager::LoadResource(_T("help_plugin.zip")))
-    NotifyMissingFile(_T("help_plugin.zip"));
+    if (!Manager::LoadResource("help_plugin.zip"))
+        NotifyMissingFile("help_plugin.zip");
 
-  // initialize IDs for Help and popup menu
-  for (int i = 0; i < MAX_HELP_ITEMS; ++i)
-  {
-    idHelpMenus[i] = wxNewId();
+    // initialize IDs for Help and popup menu
+    for (int i = 0; i < MAX_HELP_ITEMS; ++i)
+    {
+        idHelpMenus[i] = wxNewId();
 
-    // dynamically connect the events
-    Connect(idHelpMenus[i], -1, wxEVT_COMMAND_MENU_SELECTED,
-            (wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction)
-            &HelpPlugin::OnFindItem);
-  }
+        // dynamically connect the events
+        Connect(idHelpMenus[i], -1, wxEVT_COMMAND_MENU_SELECTED,
+                (wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction)
+                &HelpPlugin::OnFindItem);
+    }
 
-  m_LastId = idHelpMenus[0];
-
-#ifdef __WXMSW__
-  ocx_module = LoadLibrary(_T("HHCTRL.OCX"));
-
-  if (ocx_module)
-    fp_htmlHelp = (HTMLHELP)GetProcAddress(ocx_module, HTMLHELP_NAME);
-#endif
+    m_LastId = idHelpMenus[0];
 }
 
 HelpPlugin::~HelpPlugin()
 {
-#ifdef __WXMSW__
-  if (ocx_module)
-    FreeLibrary(ocx_module);
-#endif
 }
 
-void HelpPlugin::OnAttach()
+void HelpPlugin::SetManPageDirs(MANFrame *manFrame)
 {
-    // load configuration (only saved in our config dialog)
-    HelpCommon::LoadHelpFilesVector(m_Vector);
-
-    const wxString man_prefix = _T("man:");
+    const wxString man_prefix = "man:";
     wxString all_man_dirs(man_prefix);
 
     for (HelpCommon::HelpFilesVector::const_iterator i = m_Vector.begin(); i != m_Vector.end(); ++i)
@@ -200,19 +132,35 @@ void HelpPlugin::OnAttach()
         {
             // only add ; if a dir is already set
             if (all_man_dirs.Length() > man_prefix.Length())
-                all_man_dirs += _T(";");
+                all_man_dirs += ";";
 
             all_man_dirs += i->second.name.Mid(man_prefix.Length());
         }
     }
+    manFrame->SetDirs(all_man_dirs);
+}
 
-    wxBitmap zoominbmp = wxXmlResource::Get()->LoadBitmap(_T("ZoomInBitmap"));
-    wxBitmap zoomoutbmp = wxXmlResource::Get()->LoadBitmap(_T("ZoomOutBitmap"));
+void HelpPlugin::OnAttach()
+{
+    // load configuration (only saved in our config dialog)
+    HelpCommon::LoadHelpFilesVector(m_Vector);
+
+    wxString prefix(ConfigManager::GetDataFolder() + "/help_plugin.zip#zip:/images/");
+#if wxCHECK_VERSION(3, 1, 6)
+    prefix << "svg/";
+    wxBitmapBundle zoominbmp = cbLoadBitmapBundleFromSVG(prefix + "zoomin.svg", wxSize(16, 16));
+    wxBitmapBundle zoomoutbmp = cbLoadBitmapBundleFromSVG(prefix + "zoomout.svg", wxSize(16, 16));
+#else
+    const int imageSize = Manager::Get()->GetImageSize(Manager::UIComponent::Main);
+    prefix << wxString::Format("%dx%d/", imageSize, imageSize);
+    wxBitmap zoominbmp = cbLoadBitmap(prefix + "zoomin.png");
+    wxBitmap zoomoutbmp = cbLoadBitmap(prefix + "zoomout.png");
+#endif
 
     m_manFrame = new MANFrame(Manager::Get()->GetAppWindow(), wxID_ANY, zoominbmp, zoomoutbmp);
-    m_manFrame->SetDirs(all_man_dirs);
+    SetManPageDirs(m_manFrame);
     CodeBlocksDockEvent evt(cbEVT_ADD_DOCK_WINDOW);
-    evt.name = _T("MANViewer");
+    evt.name = "MANViewer";
     evt.title = _("Man/Html pages viewer");
     evt.pWindow = m_manFrame;
     evt.dockSide = CodeBlocksDockEvent::dsRight;
@@ -221,12 +169,12 @@ void HelpPlugin::OnAttach()
     evt.minimumSize.Set(240, 160);
     Manager::Get()->ProcessEvent(evt);
 
-    int baseFont = Manager::Get()->GetConfigManager(_T("help_plugin"))->ReadInt(_T("/base_font_size"), 0);
+    int baseFont = Manager::Get()->GetConfigManager("help_plugin")->ReadInt("/base_font_size", 0);
 
     if (baseFont > 0)
         m_manFrame->SetBaseFontSize(baseFont);
 
-    if (Manager::Get()->GetConfigManager(_T("help_plugin"))->ReadBool(_T("/show_man_viewer"), false))
+    if (Manager::Get()->GetConfigManager("help_plugin")->ReadBool("/show_man_viewer", false))
         ShowMANViewer();
 }
 
@@ -247,11 +195,13 @@ void HelpPlugin::Reload()
     // reload configuration (saved in the config dialog)
     HelpCommon::LoadHelpFilesVector(m_Vector);
     BuildHelpMenu();
+    if (m_manFrame)
+        SetManPageDirs(m_manFrame);
 }
 
 void HelpPlugin::OnRelease(bool /*appShutDown*/)
 {
-    Manager::Get()->GetConfigManager(_T("help_plugin"))->Write(_T("/base_font_size"), m_manFrame->GetBaseFontSize());
+    Manager::Get()->GetConfigManager("help_plugin")->Write("/base_font_size", m_manFrame->GetBaseFontSize());
     CodeBlocksDockEvent evt(cbEVT_REMOVE_DOCK_WINDOW);
     evt.pWindow = m_manFrame;
     Manager::Get()->ProcessEvent(evt);
@@ -267,7 +217,7 @@ void HelpPlugin::BuildHelpMenu()
     for (it = m_Vector.begin(); it != m_Vector.end(); ++it, ++counter)
     {
         if (counter == HelpCommon::getDefaultHelpIndex())
-            AddToHelpMenu(idHelpMenus[counter], it->first + _T("\tF1"), it->second.readFromIni);
+            AddToHelpMenu(idHelpMenus[counter], it->first + "\tF1", it->second.readFromIni);
         else
             AddToHelpMenu(idHelpMenus[counter], it->first, it->second.readFromIni);
     }
@@ -310,9 +260,6 @@ void HelpPlugin::BuildModuleMenu(const ModuleType type, wxMenu *menu, const File
 
   if (type == mtEditorManager)
   {
-    if (m_Vector.size() != 0)
-      menu->AppendSeparator();
-
     // add entries in popup menu
     int counter = 0;
     HelpCommon::HelpFilesVector::iterator it;
@@ -321,10 +268,12 @@ void HelpPlugin::BuildModuleMenu(const ModuleType type, wxMenu *menu, const File
     for (it = m_Vector.begin(); it != m_Vector.end(); ++it)
       AddToPopupMenu(sub_menu, idHelpMenus[counter++], it->first, it->second.readFromIni);
 
-    wxMenuItem *locate_in_menu = new wxMenuItem(0, wxID_ANY, _("&Locate in"), _T(""), wxITEM_NORMAL);
+    const wxString label = _("&Locate in");
+    wxMenuItem *locate_in_menu = new wxMenuItem(0, wxID_ANY, label, "", wxITEM_NORMAL);
     locate_in_menu->SetSubMenu(sub_menu);
 
-    menu->Append(locate_in_menu);
+    const int position = Manager::Get()->GetPluginManager()->FindSortedMenuItemPosition(*menu, label);
+    menu->Insert(position, locate_in_menu);
   }
 }
 
@@ -333,37 +282,20 @@ bool HelpPlugin::BuildToolBar(wxToolBar * /*toolBar*/)
     return false;
 }
 
-void HelpPlugin::AddToHelpMenu(int id, const wxString &help, bool
-#ifdef __WXMSW__
-    fromIni
-#endif
-)
+void HelpPlugin::AddToHelpMenu(int id, const wxString &help, cb_unused bool fromIni)
 {
-  if (!m_pMenuBar)
-    return;
+    if (!m_pMenuBar)
+        return;
 
-  int pos = m_pMenuBar->FindMenu(_("&Help"));
-
-  if (pos != wxNOT_FOUND)
-  {
-    wxMenu *helpMenu = m_pMenuBar->GetMenu(pos);
-
-    if (id == idHelpMenus[0])
-      helpMenu->AppendSeparator();
-
-#ifdef __WXMSW__
-    if (fromIni)
+    const int pos = m_pMenuBar->FindMenu(_("&Help"));
+    if (pos != wxNOT_FOUND)
     {
-      wxMenuItem *mitem = new wxMenuItem(0, id, help);
-      wxFont &font = mitem->GetFont();
-      font.SetWeight(wxFONTWEIGHT_BOLD);
-      mitem->SetFont(font);
-      helpMenu->Append(mitem);
+        wxMenu *helpMenu = m_pMenuBar->GetMenu(pos);
+        if (id == idHelpMenus[0])
+            helpMenu->AppendSeparator();
+
+        helpMenu->Append(id, help);
     }
-    else
-#endif
-      helpMenu->Append(id, help);
-  }
 }
 
 void HelpPlugin::RemoveFromHelpMenu(int id, const wxString & /*help*/)
@@ -384,11 +316,7 @@ void HelpPlugin::RemoveFromHelpMenu(int id, const wxString & /*help*/)
     // remove separator too (if it's the last thing left)
     mi = helpMenu->FindItemByPosition(helpMenu->GetMenuItemCount() - 1);
 
-    #if wxCHECK_VERSION(2, 9, 0)
     if (mi && (mi->GetKind() == wxITEM_SEPARATOR || mi->GetItemLabelText().IsEmpty()))
-    #else
-    if (mi && (mi->GetKind() == wxITEM_SEPARATOR || mi->GetText().IsEmpty()))
-    #endif
     {
       helpMenu->Remove(mi);
       delete mi;
@@ -447,7 +375,7 @@ void HelpPlugin::ShowMANViewer(bool show)
     Manager::Get()->ProcessEvent(evt);
 
     // update user prefs
-    Manager::Get()->GetConfigManager(_T("help_plugin"))->Write(_T("/show_man_viewer"), show);
+    Manager::Get()->GetConfigManager("help_plugin")->Write("/show_man_viewer", show);
 }
 
 void HelpPlugin::OnUpdateUI(wxUpdateUIEvent& /*event*/)
@@ -461,8 +389,8 @@ void HelpPlugin::OnUpdateUI(wxUpdateUIEvent& /*event*/)
 
 void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool openEmbeddedViewer, HelpCommon::StringCase keyCase, const wxString &defkeyword, const wxString &c_keyword)
 {
-  const static wxString http_prefix(_T("http://"));
-  const static wxString man_prefix(_T("man:"));
+  const static wxString http_prefix("http://");
+  const static wxString man_prefix("man:");
   wxString helpfile(c_helpfile);
 
   // Patch by Yorgos Pagles: Use the new attributes to calculate the keyword
@@ -473,43 +401,38 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
   else if (keyCase == HelpCommon::LowerCase)
     keyword.MakeLower();
 
-  helpfile.Replace(_T("$(keyword)"), keyword);
+  helpfile.Replace("$(keyword)", keyword);
   Manager::Get()->GetMacrosManager()->ReplaceMacros(helpfile);
 
   if (isExecutable)
   {
-    Manager::Get()->GetLogManager()->DebugLog(_T("Executing ") + helpfile);
+    Manager::Get()->GetLogManager()->DebugLog("Executing " + helpfile);
     wxExecute(helpfile);
     return;
   }
 
   // Support C::B scripts
-  if (wxFileName(helpfile).GetExt() == _T("script"))
+  if (wxFileName(helpfile).GetExt() == "script")
   {
-      if (Manager::Get()->GetScriptingManager()->LoadScript(helpfile))
-      {
-        // help scripts must contain a function with the following signature:
-        // function SearchHelp(keyword)
-        try
-        {
-            SqPlus::SquirrelFunction<void> f("SearchHelp");
-            f(keyword);
-        }
-        catch (SquirrelError& e)
-        {
-            Manager::Get()->GetScriptingManager()->DisplayErrors(&e);
-        }
-      }
-      else
-        Manager::Get()->GetLogManager()->DebugLog(_T("Couldn't run script"));
+    ScriptingManager *scriptMgr = Manager::Get()->GetScriptingManager();
+    if (scriptMgr->LoadScript(helpfile))
+    {
+      // help scripts must contain a function with the following signature:
+      // function SearchHelp(keyword)
+      ScriptBindings::Caller caller(scriptMgr->GetVM());
+      if (!caller.CallByName1(_SC("SearchHelp"), &keyword))
+        scriptMgr->DisplayErrors(true);
+    }
+    else
+      Manager::Get()->GetLogManager()->DebugLog("Couldn't run script");
 
-      return;
+    return;
   }
 
   // Operate on help html file links inside embedded viewer
-  if (openEmbeddedViewer && wxFileName(helpfile).GetExt().Mid(0, 3).CmpNoCase(_T("htm")) == 0)
+  if (openEmbeddedViewer && wxFileName(helpfile).GetExt().Mid(0, 3).CmpNoCase("htm") == 0)
   {
-    Manager::Get()->GetLogManager()->DebugLog(_T("Launching ") + helpfile);
+    Manager::Get()->GetLogManager()->DebugLog("Launching " + helpfile);
     cbMimePlugin* p = Manager::Get()->GetPluginManager()->GetMIMEHandlerForFile(helpfile);
     if (p)
       p->OpenFile(helpfile);
@@ -524,7 +447,7 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
   // Operate on help http (web) links
   if (helpfile.Mid(0, http_prefix.size()).CmpNoCase(http_prefix) == 0)
   {
-    Manager::Get()->GetLogManager()->DebugLog(_T("Launching ") + helpfile);
+    Manager::Get()->GetLogManager()->DebugLog("Launching " + helpfile);
     wxLaunchDefaultBrowser(helpfile);
     return;
   }
@@ -532,32 +455,32 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
   // Operate on man pages
   if (helpfile.Mid(0, man_prefix.size()).CmpNoCase(man_prefix) == 0)
   {
-    if (reinterpret_cast<MANFrame *>(m_manFrame)->SearchManPage(c_helpfile, keyword))
-      Manager::Get()->GetLogManager()->DebugLog(_T("Couldn't find man page"));
+    if (reinterpret_cast<MANFrame *>(m_manFrame)->SearchManPage(keyword))
+      Manager::Get()->GetLogManager()->DebugLog("Couldn't find man page");
     else
-      Manager::Get()->GetLogManager()->DebugLog(_T("Launching man page"));
+      Manager::Get()->GetLogManager()->DebugLog("Launching man page");
 
     ShowMANViewer();
     return;
   }
 
 #ifdef __WXMSW__
-  if (helpfile.StartsWith(_T("ms-xhelp:///")))
+  if (helpfile.StartsWith("ms-xhelp:///"))
   {
-    Manager::Get()->GetLogManager()->DebugLog(_T("Launching ") + helpfile);
+    Manager::Get()->GetLogManager()->DebugLog("Launching " + helpfile);
     ShellExecute(0, 0, helpfile.c_str(), 0, 0, SW_SHOWDEFAULT);
     return;
   }
 #endif // __WXMSW__
 
   wxFileName the_helpfile = wxFileName(helpfile);
-  Manager::Get()->GetLogManager()->DebugLog(_T("Help File is ") + helpfile);
+  Manager::Get()->GetLogManager()->DebugLog("Help File is " + helpfile);
 
   if (!(the_helpfile.FileExists()))
   {
     wxString msg;
     msg << _("Couldn't find the help file:\n")
-        << the_helpfile.GetFullPath() << _("\n")
+        << the_helpfile.GetFullPath() << '\n'
         << _("Do you want to run the associated program anyway?");
     if (!(cbMessageBox(msg, _("Warning"), wxICON_WARNING | wxYES_NO | wxNO_DEFAULT) == wxID_YES))
         return;
@@ -569,7 +492,7 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
   // Operate on help files with keyword search (windows only)
   if (!keyword.IsEmpty())
   {
-    if (ext.CmpNoCase(_T("hlp")) == 0)
+    if (ext.CmpNoCase("hlp") == 0)
     {
       wxWinHelpController HelpCtl;
       HelpCtl.Initialize(helpfile);
@@ -577,7 +500,7 @@ void HelpPlugin::LaunchHelp(const wxString &c_helpfile, bool isExecutable, bool
       return;
     }
 
-    if ((ext.CmpNoCase(_T("chm")) == 0) || (ext.CmpNoCase(_T("col")) == 0))
+    if ((ext.CmpNoCase("chm") == 0) || (ext.CmpNoCase("col") == 0))
     {
       LaunchCHMThread *p_thread = new LaunchCHMThread(helpfile, keyword);
       p_thread->Create();
