@@ -15,14 +15,16 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 7109 $
-* $Id: wxsadvqppchild.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
-* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxsadvqppchild.cpp $
+* $Revision: 10688 $
+* $Id: wxsadvqppchild.cpp 10688 2016-01-22 12:24:56Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxsadvqppchild.cpp $
 */
 
 #include "wxsadvqppchild.h"
 
-wxsAdvQPPChild::wxsAdvQPPChild(wxsAdvQPP* _Parent,const wxString Title):
+#include <prep.h>
+
+wxsAdvQPPChild::wxsAdvQPPChild(wxsAdvQPP* _Parent,cb_unused const wxString Title):
     Parent(_Parent)
 {
 }
