@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 7109 $
-* $Id: wxsdimensionproperty.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
-* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/properties/wxsdimensionproperty.cpp $
+* $Revision: 12197 $
+* $Id: wxsdimensionproperty.cpp 12197 2020-08-11 08:14:14Z fuscated $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/properties/wxsdimensionproperty.cpp $
 */
 
 #include "wxsdimensionproperty.h"
@@ -33,6 +33,7 @@ wxString wxsDimensionData::GetPixelsCode(wxsCoderContext* Context)
             return wxString::Format(_T("wxDLG_UNIT(%s,wxSize(%ld,0)).GetWidth()"),Context->m_WindowParent.c_str(),Value);
         }
 
+        case wxsUnknownLanguage: // fall-through
         default:
         {
             wxsCodeMarks::Unknown(_T("wxsDimensionData::GetPixelsCode"),Context->m_Language);
@@ -77,8 +78,8 @@ wxsDimensionProperty::wxsDimensionProperty(
 void wxsDimensionProperty::PGCreate(wxsPropertyContainer* Object,wxPropertyGridManager* Grid,wxPGId Parent)
 {
     wxPGId DUId;
-    PGRegister(Object,Grid,Grid->AppendIn(Parent,NEW_IN_WXPG14X wxIntProperty(GetPGName(),wxPG_LABEL,VALUE)),DIM_VALUE);
-    PGRegister(Object,Grid,DUId = Grid->AppendIn(Parent,NEW_IN_WXPG14X wxBoolProperty(PGDUName,wxPG_LABEL,UNITS)),DIM_UNITS);
+    PGRegister(Object,Grid,Grid->AppendIn(Parent,new wxIntProperty(GetPGName(),wxPG_LABEL,VALUE)),DIM_VALUE);
+    PGRegister(Object,Grid,DUId = Grid->AppendIn(Parent,new wxBoolProperty(PGDUName,wxPG_LABEL,UNITS)),DIM_UNITS);
     Grid->SetPropertyAttribute(DUId,wxPG_BOOL_USE_CHECKBOX,1L,wxPG_RECURSE);
 }
 
@@ -93,6 +94,9 @@ bool wxsDimensionProperty::PGRead(wxsPropertyContainer* Object,wxPropertyGridMan
         case DIM_UNITS:
             UNITS = Grid->GetPropertyValue(Id).GetBool();
             return true;
+
+        default:
+            break;
     }
     return false;
 }
@@ -108,6 +112,9 @@ bool wxsDimensionProperty::PGWrite(wxsPropertyContainer* Object,wxPropertyGridMa
         case DIM_UNITS:
             Grid->SetPropertyValue(Id,UNITS);
             return true;
+
+        default:
+            break;
     }
     return false;
 }
