@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 7109 $
-* $Id: wxsstyle.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
-* $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/contrib/wxSmith/wxwidgets/wxsstyle.cpp $
+* $Revision: 10688 $
+* $Id: wxsstyle.cpp 10688 2016-01-22 12:24:56Z mortenmacfly $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/contrib/wxSmith/wxwidgets/wxsstyle.cpp $
 */
 
 #include "wxsstyle.h"
@@ -118,6 +118,7 @@ wxString wxsStyleSet::GetString(long Bits,bool IsExtra,wxsCodingLang Language) c
             return Result;
         }
 
+        case wxsUnknownLanguage: // fall-through
         default:
         {
             wxsCodeMarks::Unknown(_T("wxsStyleSet::BitsToString"),Language);
