@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 7109 $
- * $Id: todosettingsdlg.cpp 7109 2011-04-15 11:53:16Z mortenmacfly $
- * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/todo/todosettingsdlg.cpp $
+ * $Revision: 13091 $
+ * $Id: todosettingsdlg.cpp 13091 2022-12-03 08:40:20Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/todo/todosettingsdlg.cpp $
  */
 
 #include "sdk.h"
@@ -21,9 +21,9 @@
 ToDoSettingsDlg::ToDoSettingsDlg(wxWindow* parent)
 {
     //ctor
-    wxXmlResource::Get()->LoadPanel(this, parent, _T("ToDoSettingsDlg"));
-    bool checked = Manager::Get()->GetConfigManager(_T("todo_list"))->ReadBool(_T("auto_refresh"), true);
-    bool standalone = Manager::Get()->GetConfigManager(_T("todo_list"))->ReadBool(_T("stand_alone"), true);
+    wxXmlResource::Get()->LoadPanel(this, parent, "ToDoSettingsDlg");
+    bool checked = Manager::Get()->GetConfigManager("todo_list")->ReadBool("auto_refresh", true);
+    bool standalone = Manager::Get()->GetConfigManager("todo_list")->ReadBool("stand_alone", true);
     XRCCTRL(*this, "chkAutoRefresh", wxCheckBox)->SetValue(checked);
     XRCCTRL(*this, "chkMessagesPane", wxCheckBox)->SetValue(!standalone);
 }
@@ -37,6 +37,6 @@ void ToDoSettingsDlg::OnApply()
 {
     bool checked = XRCCTRL(*this, "chkAutoRefresh", wxCheckBox)->GetValue();
     bool standalone = !(XRCCTRL(*this, "chkMessagesPane", wxCheckBox)->GetValue());
-    Manager::Get()->GetConfigManager(_T("todo_list"))->Write(_T("auto_refresh"), checked);
-    Manager::Get()->GetConfigManager(_T("todo_list"))->Write(_T("stand_alone"), standalone);
+    Manager::Get()->GetConfigManager("todo_list")->Write("auto_refresh", checked);
+    Manager::Get()->GetConfigManager("todo_list")->Write("stand_alone", standalone);
 }
