@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 8524 $
- * $Id: windowsxplooknfeel.cpp 8524 2012-11-07 16:34:06Z thomasdenk $
- * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/plugins/xpmanifest/windowsxplooknfeel.cpp $
+ * $Revision: 12999 $
+ * $Id: windowsxplooknfeel.cpp 12999 2022-11-01 13:12:28Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/plugins/xpmanifest/windowsxplooknfeel.cpp $
  */
 
 #include <sdk.h>
@@ -54,7 +54,7 @@ int WindowsXPLookNFeel::Execute()
 	}
 
 	wxArrayString targetNames;
-	ProjectBuildTarget* target = 0L;
+	ProjectBuildTarget* target = nullptr;
 	for (int i = 0; i < project->GetBuildTargetsCount(); ++i)
 	{
 		ProjectBuildTarget* tgt = project->GetBuildTarget(i);
@@ -62,7 +62,7 @@ int WindowsXPLookNFeel::Execute()
 		{
 			if (tgt->GetTargetType() != ttExecutable)
 			{
-				Manager::Get()->GetLogManager()->DebugLog(F(_T("WindowsXPLookNFeel: Ignoring target '%s'"), tgt->GetTitle().wx_str()));
+				Manager::Get()->GetLogManager()->DebugLog(wxString::Format("WindowsXPLookNFeel: Ignoring target '%s'", tgt->GetTitle()));
 				continue;
 			}
 			targetNames.Add(tgt->GetTitle());
@@ -79,7 +79,7 @@ int WindowsXPLookNFeel::Execute()
 	else if (targetNames.GetCount() > 1)
 	{
 		// more than one executable target... ask...
-		target = 0L;
+		target = nullptr;
 		int targetIndex = project->SelectTarget(-1, true);
 		if (targetIndex > -1)
 			target = project->GetBuildTarget(targetIndex);
@@ -95,9 +95,9 @@ int WindowsXPLookNFeel::Execute()
 		wxString filename = target->GetOutputFilename();
 		filename << _T(".Manifest");
 		wxFileName fname(filename);
-		fname.Normalize(wxPATH_NORM_ALL & ~wxPATH_NORM_CASE, project->GetBasePath());
+		fname.Normalize(wxPATH_NORM_DOTS | wxPATH_NORM_TILDE | wxPATH_NORM_ABSOLUTE | wxPATH_NORM_LONG | wxPATH_NORM_SHORTCUT, project->GetBasePath());
 		filename = fname.GetFullPath();
-		Manager::Get()->GetLogManager()->DebugLog(F(_T("WindowsXPLookNFeel: Creating Manifest '%s'"), filename.wx_str()));
+		Manager::Get()->GetLogManager()->DebugLog(wxString::Format("WindowsXPLookNFeel: Creating Manifest '%s'", filename));
 
 		wxString buffer;
 		buffer << _T("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>") << _T('\n');
