@@ -2,14 +2,15 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 9044 $
- * $Id: multiselectdlg.cpp 9044 2013-05-04 04:40:48Z mortenmacfly $
- * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/multiselectdlg.cpp $
+ * $Revision: 11996 $
+ * $Id: multiselectdlg.cpp 11996 2020-03-26 21:04:41Z fuscated $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/multiselectdlg.cpp $
  */
 
 #include "sdk_precomp.h"
 
 #ifndef CB_PRECOMP
+    #include <wx/button.h>
     #include <wx/checklst.h>
     #include <wx/msgdlg.h>
     #include <wx/stattext.h>
@@ -17,8 +18,6 @@
     #include "globals.h"
 #endif
 
-#include <wx/textdlg.h>
-
 #include "multiselectdlg.h"
 
 BEGIN_EVENT_TABLE(MultiSelectDlg, wxScrollingDialog)
@@ -41,6 +40,10 @@ MultiSelectDlg::MultiSelectDlg(wxWindow* parent,
     SetTitle(title);
     XRCCTRL(*this, "lblLabel", wxStaticText)->SetLabel(label);
     Init(items, wildcard);
+
+    wxButton *buttonOK = XRCCTRL(*this, "wxID_OK", wxButton);
+    buttonOK->SetDefault();
+    buttonOK->SetFocus();
 }
 
 MultiSelectDlg::MultiSelectDlg(wxWindow* parent,
@@ -51,10 +54,15 @@ MultiSelectDlg::MultiSelectDlg(wxWindow* parent,
 {
     //ctor
     wxXmlResource::Get()->LoadObject(this, parent, _T("dlgGenericMultiSelect"),_T("wxScrollingDialog"));
+    XRCCTRL(*this, "wxID_OK", wxButton)->SetDefault();
 
     SetTitle(title);
     XRCCTRL(*this, "lblLabel", wxStaticText)->SetLabel(label);
     Init(items, selectall ? _T("*") : _T(""));
+
+    wxButton *buttonOK = XRCCTRL(*this, "wxID_OK", wxButton);
+    buttonOK->SetDefault();
+    buttonOK->SetFocus();
 }
 
 MultiSelectDlg::~MultiSelectDlg()
@@ -141,10 +149,10 @@ void MultiSelectDlg::SelectWildCard(const wxString& wild, bool select, bool clea
 
 void MultiSelectDlg::OnWildcard(cb_unused wxCommandEvent& event)
 {
-    wxString wild = wxGetTextFromUser(_("Enter a selection wildcard\n(e.g. \"dlg*.cpp\" "
+    wxString wild = cbGetTextFromUser(_("Enter a selection wildcard\n(e.g. \"dlg*.cpp\" "
                                         "would select all files starting with \"dlg\" and "
                                         "ending in \".cpp\")\nSeparate multiple masks with \";\":"),
-                                        _("Wildcard selection"));
+                                      _("Wildcard selection"), wxString(), this);
     if (wild.IsEmpty())
         return;
 
