@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 8541 $
- * $Id: projectsfilemasksdlg.cpp 8541 2012-11-10 18:37:28Z thomasdenk $
- * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/projectsfilemasksdlg.cpp $
+ * $Revision: 11996 $
+ * $Id: projectsfilemasksdlg.cpp 11996 2020-03-26 21:04:41Z fuscated $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/projectsfilemasksdlg.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -19,7 +19,6 @@
     #include "globals.h"
 #endif
 
-#include <wx/textdlg.h>
 #include "projectsfilemasksdlg.h"
 
 BEGIN_EVENT_TABLE(ProjectsFileMasksDlg, wxScrollingDialog)
@@ -37,6 +36,7 @@ ProjectsFileMasksDlg::ProjectsFileMasksDlg(wxWindow* parent, FilesGroupsAndMasks
     m_LastListSelection(0)
 {
     wxXmlResource::Get()->LoadObject(this, parent, _T("dlgProjectsFileMasks"),_T("wxScrollingDialog"));
+    XRCCTRL(*this, "wxID_OK", wxButton)->SetDefault();
 
     RebuildList();
 }
@@ -86,8 +86,8 @@ void ProjectsFileMasksDlg::OnUpdateUI(cb_unused wxUpdateUIEvent& event)
 
 void ProjectsFileMasksDlg::OnAdd(cb_unused wxCommandEvent& event)
 {
-    wxString groupName = wxGetTextFromUser(_("Enter the new group name:"),
-                                            _("New group"));
+    wxString groupName = cbGetTextFromUser(_("Enter the new group name:"),
+                                            _("New group"), wxString(), this);
     if (groupName.IsEmpty())
         return;
     m_FileGroupsAndMasksCopy.AddGroup(groupName);
@@ -102,8 +102,8 @@ void ProjectsFileMasksDlg::OnEdit(cb_unused wxCommandEvent& event)
 {
     wxListBox* pList = XRCCTRL(*this, "lstCategories", wxListBox);
     wxString oldName = pList->GetStringSelection();
-    wxString groupName = wxGetTextFromUser(_("Rename the group:"),
-                                            _("Edit group"), oldName);
+    wxString groupName = cbGetTextFromUser(_("Rename the group:"),
+                                            _("Edit group"), oldName, this);
     if (!groupName.IsEmpty() && groupName != oldName)
     {
         m_FileGroupsAndMasksCopy.RenameGroup(pList->GetSelection(), groupName);
