@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU Lesser General Public License, version 3
  * http://www.gnu.org/licenses/lgpl-3.0.html
  *
- * $Revision: 9441 $
- * $Id: templatemanager.cpp 9441 2013-11-09 12:59:13Z mortenmacfly $
- * $HeadURL: http://svn.code.sf.net/p/codeblocks/code/branches/release-xx.yy/src/sdk/templatemanager.cpp $
+ * $Revision: 13437 $
+ * $Id: templatemanager.cpp 13437 2024-01-31 11:51:59Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/branches/release-25.03/src/sdk/templatemanager.cpp $
  */
 
 #include "sdk_precomp.h"
@@ -25,7 +25,6 @@
     #include "globals.h"
     #include "compilerfactory.h"
     #include "cbplugin.h"
-    #include "cbproject.h"
 #endif
 
 #include <wx/filedlg.h>
@@ -33,8 +32,8 @@
 #include "filefilters.h"
 #include "newfromtemplatedlg.h"
 
-template<> TemplateManager* Mgr<TemplateManager>::instance = nullptr;
-template<> bool  Mgr<TemplateManager>::isShutdown = false;
+template<> TemplateManager* DLLIMPORT Mgr<TemplateManager>::instance = nullptr;
+template<> bool DLLIMPORT Mgr<TemplateManager>::isShutdown = false;
 
 TemplateManager::TemplateManager()
 {
@@ -79,12 +78,12 @@ void TemplateManager::LoadUserTemplates()
         ok = dir.GetNext(&filename);
     }
 
-    Manager::Get()->GetLogManager()->DebugLog(F(_T("%d user templates loaded"), m_UserTemplates.GetCount()));
+    Manager::Get()->GetLogManager()->DebugLog(wxString::Format("%zu user templates loaded", m_UserTemplates.GetCount()));
 }
 
 cbProject* TemplateManager::New(TemplateOutputType initial, wxString* pFilename)
 {
-    cbProject* prj = NULL;
+    cbProject* prj = nullptr;
 
     LoadUserTemplates();
     NewFromTemplateDlg dlg(initial, m_UserTemplates);
@@ -101,7 +100,7 @@ cbProject* TemplateManager::New(TemplateOutputType initial, wxString* pFilename)
 
 cbProject* TemplateManager::NewFromTemplate(NewFromTemplateDlg& dlg, wxString* pFilename)
 {
-    cbProject* prj = NULL;
+    cbProject* prj = nullptr;
     cbWizardPlugin* wiz = dlg.GetWizard();
     if (wiz)
     {
@@ -122,11 +121,11 @@ cbProject* TemplateManager::NewFromTemplate(NewFromTemplateDlg& dlg, wxString* p
 
 cbProject* TemplateManager::NewProjectFromUserTemplate(NewFromTemplateDlg& dlg, wxString* pFilename)
 {
-    cbProject* prj = NULL;
+    cbProject* prj = nullptr;
     if (!dlg.SelectedUserTemplate())
     {
         Manager::Get()->GetLogManager()->DebugLog(_T("TemplateManager::NewProjectFromUserTemplate() called when no user template was selected ?!?"));
-        return NULL;
+        return nullptr;
     }
 
     wxString path = Manager::Get()->GetConfigManager(_T("template_manager"))->Read(_T("/projects_path"));
@@ -135,7 +134,7 @@ cbProject* TemplateManager::NewProjectFromUserTemplate(NewFromTemplateDlg& dlg,
     path = ChooseDirectory(nullptr, _("Choose a directory to create the new project"),
                         path, _T(""), false, true);
     if (path.IsEmpty())
-        return NULL;
+        return nullptr;
     else if (path.Mid(path.Length() - 1) == wxFILE_SEP_PATH)
         path.RemoveLast();
 
@@ -161,8 +160,8 @@ cbProject* TemplateManager::NewProjectFromUserTemplate(NewFromTemplateDlg& dlg,
     templ << sep << dlg.GetSelectedUserTemplate();
     if (!wxDirExists(templ))
     {
-        Manager::Get()->GetLogManager()->DebugLog(F(_T("Cannot open user-template source path '%s'!"), templ.wx_str()));
-        return NULL;
+        Manager::Get()->GetLogManager()->DebugLog(wxString::Format("Cannot open user-template source path '%s'!", templ));
+        return nullptr;
     }
 
     // copy files
@@ -187,11 +186,7 @@ cbProject* TemplateManager::NewProjectFromUserTemplate(NewFromTemplateDlg& dlg,
             ++count;
         }
         else
-            #if wxCHECK_VERSION(2, 9, 0)
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("Failed copying %s to %s"), src.wx_str(), dst.wx_str()));
-            #else
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("Failed copying %s to %s"), src.c_str(), dst.c_str()));
-            #endif
+            Manager::Get()->GetLogManager()->DebugLog(wxString::Format("Failed copying %s to %s", src, dst));
     }
     if (count != total_count)
         cbMessageBox(_("Some files could not be loaded with the template..."), _("Error"), wxICON_ERROR);
@@ -204,7 +199,7 @@ cbProject* TemplateManager::NewProjectFromUserTemplate(NewFromTemplateDlg& dlg,
         {
             // ask to rename the project file, if need be
             wxFileName fname(project_filename);
-            wxString newname = wxGetTextFromUser(_("If you want, you can change the project's filename here (without extension):"), _("Change project's filename"), fname.GetName());
+            wxString newname = cbGetTextFromUser(_("If you want, you can change the project's filename here (without extension):"), _("Change project's filename"), fname.GetName());
             if (!newname.IsEmpty() && newname != fname.GetName())
             {
                 fname.SetName(newname);
@@ -263,8 +258,16 @@ void TemplateManager::SaveUserTemplate(cbProject* prj)
         return;
     }
 
-    // check if it exists and ask a different title
+    // get default template title
     wxString title = prj->GetTitle();
+
+    // filter title, removing all illegal filename characters
+    wxFileName titleFileName(title) ;
+    wxString forbidden = titleFileName.GetForbiddenChars();
+    for (size_t i=0; i<forbidden.Length(); ++i)
+        title.Replace(wxString(forbidden[i]), wxT(""), true);
+
+    // check if it exists and ask a different title
     while (true)
     {
         // ask for template title (unique)
@@ -296,21 +299,13 @@ void TemplateManager::SaveUserTemplate(cbProject* prj)
     {
         wxString src = (*it)->file.GetFullPath();
         wxString dst = templ + (*it)->relativeToCommonTopLevelPath;
-        #if wxCHECK_VERSION(2, 9, 0)
-        Manager::Get()->GetLogManager()->DebugLog(F(_T("Copying %s to %s"), src.wx_str(), dst.wx_str()));
-        #else
-        Manager::Get()->GetLogManager()->DebugLog(F(_T("Copying %s to %s"), src.c_str(), dst.c_str()));
-        #endif
+        Manager::Get()->GetLogManager()->DebugLog(wxString::Format("Copying %s to %s", src, dst));
         if (!CreateDirRecursively(dst))
             Manager::Get()->GetLogManager()->DebugLog(_T("Failed creating directory for ") + dst);
         if (wxCopyFile(src, dst, true))
             ++count;
         else
-            #if wxCHECK_VERSION(2, 9, 0)
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("Failed copying %s to %s"), src.wx_str(), dst.wx_str()));
-            #else
-            Manager::Get()->GetLogManager()->DebugLog(F(_T("Failed copying %s to %s"), src.c_str(), dst.c_str()));
-            #endif
+            Manager::Get()->GetLogManager()->DebugLog(wxString::Format("Failed copying %s to %s", src, dst));
     }
 
     // cbProject doesn't have a GetRelativeToCommonTopLevelPath() function, so we simulate it here
